@@ -31,7 +31,9 @@
 #include "mxcl.library.h"
 #include "theStream.h"
 
+#ifdef HAVE_XINE
 #include <xine.h>
+#endif
 
 #include <QActionGroup>
 #include <QContextMenuEvent>
@@ -42,11 +44,13 @@
 #include <KApplication>
 #include <KLocale>
 #include <KMenu>
+#include <KMimeType>
 #include <KStandardDirs>
 
 #include <Phonon/AudioOutput>
 #include <Phonon/MediaController>
 #include <Phonon/MediaObject>
+#include <Phonon/MediaSource>
 #include <Phonon/Path>
 #include <Phonon/SeekSlider>
 #include <Phonon/VideoWidget>
@@ -57,6 +61,10 @@
 #include <Solid/Device>
 #include <Solid/OpticalDisc>
 
+#ifdef Q_WS_WIN
+#include <windows.h>
+#endif
+
 using Phonon::AudioOutput;
 using Phonon::MediaObject;
 using Phonon::VideoWidget;
@@ -113,8 +121,8 @@ VideoWindow::VideoWindow( QWidget *parent )
         turnOff->setProperty( TheStream::CHANNEL_PROPERTY, -1 );
         connect( turnOff, SIGNAL( triggered() ), this, SLOT( slotSetSubtitle() ) );
 
-        QAction* seperator = new QAction( m_subLanguages );
-        seperator->setSeparator( true );
+        QAction* separator = new QAction( m_subLanguages );
+        separator->setSeparator( true );
     }
     {
         m_audioLanguages->setExclusive( true );
@@ -123,8 +131,8 @@ VideoWindow::VideoWindow( QWidget *parent )
         autoLang->setCheckable( true );
         connect( autoLang, SIGNAL( triggered() ), this, SLOT( slotSetAudio() ) );
 
-        QAction* seperator = new QAction( m_audioLanguages );
-        seperator->setSeparator( true );
+        QAction* separator = new QAction( m_audioLanguages );
+        separator->setSeparator( true );
     }
 
     connect( m_media, SIGNAL(stateChanged(Phonon::State,Phonon::State)), this, SLOT(stateChanged(Phonon::State,Phonon::State)) );
@@ -173,7 +181,11 @@ VideoWindow::~VideoWindow()
         m_audioPath.insertEffect( faderEffect );
         faderEffect->setFadeCurve( Phonon::VolumeFaderEffect::Fade12Decibel );
         faderEffect->fadeOut( 500 );
+#ifndef Q_WS_WIN
         ::usleep( 700000 );
+#else
+        ::Sleep( 700 );
+#endif
     }
     else
         m_media->stop(); //hangs if its destroyed while paused?
@@ -191,9 +203,15 @@ VideoWindow::load( const KUrl &url )
     DEBUG_BLOCK
     mxcl::WaitCursor allocateOnStack;
     eject();
-    m_media->setCurrentSource( url );
+
+    KMimeType::Ptr mimeType = KMimeType::findByUrl( url );
+    debug() << "detected mimetype: " << mimeType->name();
+    if( mimeType->is( "application/x-cd-image" ) || mimeType->is( "inode/directory" ) )
+        m_media->setCurrentSource( Phonon::MediaSource( Phonon::Dvd, url.path() ) );
+    else
+        m_media->setCurrentSource( url );
     m_justLoaded = true;
-	m_adjustedSize=false;
+    m_adjustedSize=false;
     return true;
 }
 
@@ -450,8 +468,7 @@ void
 VideoWindow::resetZoom()
 {
     TheStream::profile().deleteEntry( "Preferred Size" );
-    if( mainWindow() )
-        mainWindow()->adjustSize();
+    window()->adjustSize();
 }
 
 qint64
@@ -533,9 +550,9 @@ debug() << "chapters: " << m_controller->availableChapters() << " titles: " << m
         {
            if( mainWindow() )
              ( (QWidget*) mainWindow() )->adjustSize();
-           m_adjustedSize=true;
-           debug() << "adjusting size to video resolution";
-	}
+          m_adjustedSize=true;
+          debug() << "adjusting size to video resolution";
+        }     
     }
     emit stateChanged( state( currentState ) ); 
 }
@@ -662,6 +679,7 @@ VideoWindow::slotSetAudio()
 void
 VideoWindow::toggleDVDMenu()
 {
+#ifdef HAVE_XINE
     if( m_xineStream )
     {
         xine_event_t e;
@@ -670,6 +688,7 @@ VideoWindow::toggleDVDMenu()
         e.data_length = 0;
         xine_event_send( m_xineStream, &e );
     }
+#endif
 }
 
 int
@@ -708,22 +727,40 @@ VideoWindow::nextChapter()
   }
 
 void
-VideoWindow::tenBack()
-  {
-    qint64 newTime = m_media->currentTime() - (m_media->totalTime() / 10);
-    if (newTime > 0)
-	m_media -> seek (newTime);
-      else
-        m_media -> seek ( 0 ) ;
+VideoWindow::tenPercentBack()
+{
+  qint64 newTime = m_media->currentTime() - (m_media->totalTime() / 10);
+  if (newTime > 0)
+    m_media -> seek (newTime);
+  else
+    m_media -> seek ( 0 ) ;
   }
 
 void
-VideoWindow::tenForward()
-  {
-    qint64 newTime = m_media->currentTime() + (m_media->totalTime() / 10);
-    if (newTime < m_media->totalTime())
+VideoWindow::tenPercentForward()
+{
+  qint64 newTime = m_media->currentTime() + (m_media->totalTime() / 10);
+  if (newTime < m_media->totalTime())
 	m_media -> seek (newTime);
-  }
+}
+
+void
+VideoWindow::tenSecondsBack()
+{
+  qint64 newTime = m_media->currentTime() - 10;
+  if (newTime > 0)
+    m_media -> seek (newTime);
+  else
+    m_media -> seek ( 0 ) ;
+}
+
+void
+VideoWindow::tenSecondsForward()
+{
+  qint64 newTime = m_media->currentTime() + 10;
+  if (newTime < m_media->totalTime())
+    m_media -> seek (newTime);
+}
 
 ///////////
 ///Protected
