@@ -55,21 +55,17 @@ CollectionList *CollectionList::instance()
     return m_list;
 }
 
-void CollectionList::initialize(PlaylistCollection *collection)
+void CollectionList::loadCachedItems()
 {
-    if(m_list)
+    if(!m_list)
         return;
 
-    // We have to delay initilaization here because dynamic_cast or comparing to
-    // the collection instance won't work in the PlaylistBox::Item initialization
-    // won't work until the CollectionList is fully constructed.
-
-    m_list = new CollectionList(collection);
-    m_list->setName(i18n("Collection List"));
-
-    FileHandleHash::Iterator end = Cache::instance()->end();
-    for(FileHandleHash::Iterator it = Cache::instance()->begin(); it != end; ++it)
-        new CollectionListItem(*it);
+    FileHandleHash::ConstIterator end = Cache::instance()->constEnd();
+    for(FileHandleHash::ConstIterator it = Cache::instance()->constBegin(); it != end; ++it) {
+        // This may have already been created via a loaded playlist.
+        if(!m_itemsDict.contains(it.key()))
+            new CollectionListItem(*it);
+    }
 
     SplashScreen::update();
 
@@ -86,6 +82,21 @@ void CollectionList::initialize(PlaylistCollection *collection)
 
     m_list->sort();
 
+    SplashScreen::finishedLoading();
+}
+
+void CollectionList::initialize(PlaylistCollection *collection)
+{
+    if(m_list)
+        return;
+
+    // We have to delay initialization here because dynamic_cast or comparing to
+    // the collection instance won't work in the PlaylistBox::Item initialization
+    // won't work until the CollectionList is fully constructed.
+
+    m_list = new CollectionList(collection);
+    m_list->setName(i18n("Collection List"));
+
     collection->setupPlaylist(m_list, "folder-sound");
 }
 
@@ -117,7 +128,7 @@ PlaylistItem *CollectionList::createItem(const FileHandle &file, Q3ListViewItem
 
 void CollectionList::clearItems(const PlaylistItemList &items)
 {
-    for(PlaylistItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for(PlaylistItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
         Cache::instance()->remove((*it)->file());
         clearItem(*it, false);
     }
@@ -146,7 +157,7 @@ void CollectionList::slotNewItems(const KFileItemList &items)
 {
     QStringList files;
 
-    for(KFileItemList::ConstIterator it = items.begin(); it != items.end(); ++it)
+    for(KFileItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it)
         files.append((*it).url().path());
 
     addFiles(files);
@@ -206,6 +217,8 @@ void CollectionList::clear()
 
 void CollectionList::slotCheckCache()
 {
+    loadCachedItems();
+
     PlaylistItemList invalidItems;
 
     foreach(CollectionListItem *item, m_itemsDict) {
@@ -422,7 +435,7 @@ PlaylistItem *CollectionListItem::itemForPlaylist(const Playlist *playlist)
         return this;
 
     PlaylistItemList::ConstIterator it;
-    for(it = m_children.begin(); it != m_children.end(); ++it)
+    for(it = m_children.constBegin(); it != m_children.constEnd(); ++it)
         if((*it)->playlist() == playlist)
             return *it;
     return 0;
@@ -442,7 +455,7 @@ void CollectionListItem::updateCollectionDict(const QString &oldPath, const QStr
 void CollectionListItem::repaint() const
 {
     Q3ListViewItem::repaint();
-    for(PlaylistItemList::ConstIterator it = m_children.begin(); it != m_children.end(); ++it)
+    for(PlaylistItemList::ConstIterator it = m_children.constBegin(); it != m_children.constEnd(); ++it)
         (*it)->repaint();
 }
 
@@ -479,8 +492,8 @@ CollectionListItem::~CollectionListItem()
 {
     m_shuttingDown = true;
 
-    for(PlaylistItemList::ConstIterator it = m_children.begin();
-        it != m_children.end();
+    for(PlaylistItemList::ConstIterator it = m_children.constBegin();
+        it != m_children.constEnd();
         ++it)
     {
         delete *it;
