@@ -13,14 +13,15 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <limits.h>
-#include <stdlib.h>
+#include "filehandle.h"
 
 #include <kdebug.h>
 
-#include <qfileinfo.h>
+#include <QFileInfo>
+
+#include <limits.h>
+#include <stdlib.h>
 
-#include "filehandle.h"
 #include "filehandleproperties.h"
 #include "tag.h"
 #include "cache.h"
@@ -37,13 +38,13 @@ AddNumberProperty(Seconds, tag()->seconds())
 AddNumberProperty(Bitrate, tag()->bitrate())
 AddProperty(Path, absFilePath())
 AddNumberProperty(Size, fileInfo().size())
-AddProperty(Extension, fileInfo().extension(false))
+AddProperty(Extension, fileInfo().suffix())
 
 static QString resolveSymLinks(const QFileInfo &file) // static
 {
     char real[PATH_MAX];
 
-    if(file.exists() && realpath(QFile::encodeName(file.absFilePath()).data(), real))
+    if(file.exists() && realpath(QFile::encodeName(file.absoluteFilePath()).data(), real))
         return QFile::decodeName(real);
     else
         return file.filePath();
@@ -100,8 +101,8 @@ FileHandle::FileHandle(const FileHandle &f) :
     d(f.d)
 {
     if(!d) {
-	kdDebug(65432) << "The source FileHandle was not initialized." << endl;
-	d = null().d;
+        kDebug(65432) << "The source FileHandle was not initialized.";
+        d = null().d;
     }
     d->ref();
 }
@@ -169,8 +170,8 @@ CoverInfo *FileHandle::coverInfo() const
 
 QString FileHandle::absFilePath() const
 {
-    if(d->absFilePath.isNull())
-        d->absFilePath = resolveSymLinks(d->fileInfo.absFilePath());
+    if(d->absFilePath.isEmpty())
+        d->absFilePath = resolveSymLinks(d->fileInfo.absoluteFilePath());
     return d->absFilePath;
 }
 
@@ -244,7 +245,7 @@ QStringList FileHandle::properties() // static
 
 QString FileHandle::property(const QString &name) const
 {
-    return FileHandleProperties::property(*this, name.latin1());
+    return FileHandleProperties::property(*this, name.toAscii());
 }
 
 const FileHandle &FileHandle::null() // static
@@ -262,7 +263,7 @@ void FileHandle::setup(const QFileInfo &info, const QString &path)
     if(d && !isNull())
         return;
 
-    QString fileName = path.isNull() ? info.absFilePath() : path;
+    QString fileName = path.isEmpty() ? info.absoluteFilePath() : path;
 
     FileHandle cached = Cache::instance()->value(resolveSymLinks(fileName));
 
@@ -296,3 +297,5 @@ CacheDataStream &operator>>(CacheDataStream &s, FileHandle &f)
     f.read(s);
     return s;
 }
+
+// vim: set et sw=4 tw=0 sta:
