@@ -147,6 +147,10 @@ void PlaylistSplitter::setupLayout()
 {
     setOpaqueResize(false);
 
+    // Disable the GUI until startup is complete (as indicated by PlaylistBox)
+
+    setEnabled(false);
+
     // Create a splitter to go between the playlists and the editor.
 
     QSplitter *editorSplitter = new QSplitter(Qt::Vertical, this);
@@ -156,10 +160,13 @@ void PlaylistSplitter::setupLayout()
 
     QWidget *top = new QWidget(editorSplitter);
     QVBoxLayout *topLayout = new QVBoxLayout(top);
+    topLayout->setMargin(0);
+    topLayout->setSpacing(0);
 
     m_playlistStack = new Q3WidgetStack(top, "playlistStack");
     m_playlistStack->installEventFilter(this);
     m_playlistStack->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    m_playlistStack->hide(); // Will be shown after CollectionList filled.
 
     connect(m_playlistStack, SIGNAL(aboutToShow(QWidget *)), this, SLOT(slotPlaylistChanged(QWidget *)));
 
@@ -180,6 +187,7 @@ void PlaylistSplitter::setupLayout()
             this, SLOT(slotPlaylistSelectionChanged()));
     connect(m_playlistBox, SIGNAL(signalPlaylistDestroyed(Playlist *)),
             m_editor, SLOT(slotPlaylistDestroyed(Playlist *)));
+    connect(m_playlistBox, SIGNAL(startupComplete()), SLOT(slotEnable()));
 
     insertWidget(0, m_playlistBox);
 
@@ -260,6 +268,12 @@ void PlaylistSplitter::slotPlaylistChanged(QWidget *w)
     m_newVisible = 0;
 }
 
+void PlaylistSplitter::slotEnable()
+{
+    setEnabled(true); // Ready to go.
+    m_playlistStack->show();
+}
+
 #include "playlistsplitter.moc"
 
 // vim: set et sw=4 tw=0 sta:
