@@ -23,6 +23,7 @@
  */
 
 #include <config.h>
+#include <config-audiocd.h>
 
 #include <kdemacros.h>
 extern "C"
@@ -217,7 +218,7 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 #if defined(HAVE_CDDA_IOCTL_DEVICE)
 	if (d->cd.deviceName() != drive->ioctl_device_name)
 		d->cd.setDevice(drive->ioctl_device_name, 50, false);
-#else
+#elif (defined __FreeBSD__)
 	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
 	// support for non-SCSI devices. Although it finds ATA cdroms just
 	// fine, there is no straightforward way to discover the device
@@ -252,6 +253,10 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 			d->cd.setDevice( devname );
 		}
 	}
+#else
+#ifdef __GNUC__
+	#warning audiocd ioslave is not going to work for you
+#endif
 #endif
 
 
@@ -543,13 +548,15 @@ static void app_dir(UDSEntry& e, const QString & n, size_t s)
 	e.insert( KIO::UDSEntry::UDS_MIME_TYPE, QString("inode/directory"));
 }
 
-static void app_file(UDSEntry& e, const QString & n, size_t s)
+static void app_file(UDSEntry& e, const QString & n, size_t s, const QString &mimetype = QString())
 {
 	e.clear();
 	e.insert( KIO::UDSEntry::UDS_NAME, QFile::decodeName(n.toLocal8Bit()));
 	e.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 	e.insert( KIO::UDSEntry::UDS_ACCESS, 0400);
 	e.insert( KIO::UDSEntry::UDS_SIZE, s);
+	if (!mimetype.isEmpty())
+		e.insert( KIO::UDSEntry::UDS_MIME_TYPE, mimetype);
 }
 
 void AudioCDProtocol::listDir(const KUrl & url)
@@ -691,7 +698,7 @@ void AudioCDProtocol::addEntry(const QString& trackTitle, AudioCDEncoder *encode
 		theFileSize = fileSize(firstSector, lastSector, encoder);
 	}
 	UDSEntry entry;
-	app_file(entry, trackTitle + QString(".")+encoder->fileType(), theFileSize);
+	app_file(entry, trackTitle + QString(".")+encoder->fileType(), theFileSize, encoder->mimeType());
 	listEntry(entry, false);
 }
 
@@ -927,7 +934,7 @@ void AudioCDProtocol::parseURLArgs(const KUrl & url)
 
 	QStringList tokens(query.split('&',QString::SkipEmptyParts));
 
-	for (QStringList::ConstIterator it(tokens.begin()); it != tokens.end(); ++it)
+	for (QStringList::ConstIterator it(tokens.constBegin()); it != tokens.constEnd(); ++it)
 	{
 		QString token(*it);
 
