@@ -1,6 +1,7 @@
 /*
 
     Copyright (C) 2001 Carsten Duvenhorst <duvenhorst@m2.uni-hannover.de>
+    Copyright (C) 2005 Benjamin Meyer <ben at meyerhome dot net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     Permission is also granted to link this program with the Qt
     library, treating Qt like a library that normally accompanies the
@@ -22,20 +23,32 @@
 
 */
 
+#ifndef KCMAUDIOCD_H
+#define KCMAUDIOCD_H
 
-#ifndef KAUDIOCDCONFIG_H
-#define KAUDIOCDCONFIG_H
-
+//Added by qt3to4:
+#include <Q3PtrList>
+#include <kcmodule.h>
 class KConfigDialogManager;
 
-#include "audiocdconfig.h"
-class KAudiocdModule : public AudiocdConfig
+#include "ui_audiocdconfig.h"
+
+class AudiocdConfig : public QWidget, public Ui::AudiocdConfig
+{
+public:
+  explicit AudiocdConfig( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
+class KAudiocdModule : public KCModule
 {
   Q_OBJECT
 
 public:
 
-  KAudiocdModule(QWidget *parent=0, const char *name=0);
+  explicit KAudiocdModule(QWidget *parent=0, const QVariantList &args=QVariantList());
   ~KAudiocdModule();
 
   QString quickHelp() const;
@@ -57,8 +70,8 @@ private:
 
   int getBitrateIndex(int value);
 
-  QPtrList<KConfigDialogManager> encoderSettings;
+  Q3PtrList<KConfigDialogManager> encoderSettings;
+  AudiocdConfig *audioConfig;
 };
 
-#endif // KAUDIOCDCONFIG_H
-
+#endif // KCMAUDIOCD_H
