@@ -66,6 +66,10 @@ KMixDockWidget::KMixDockWidget(KMixWindow* parent, QWidget *referenceWidget, boo
    createActions();
    //connect(this, SIGNAL(quitSelected()), kapp, SLOT(quitExtended()));
    connect(contextMenu(), SIGNAL(aboutToShow()), this, SLOT(contextMenuAboutToShow()));
+
+   ViewDockAreaPopup* dockAreaPopup = qobject_cast<ViewDockAreaPopup*>(referenceWidget);
+   if ( _volumePopup && dockAreaPopup != 0 )
+      dockAreaPopup->installEventFilter(this);
 }
 
 KMixDockWidget::~KMixDockWidget()
@@ -75,13 +79,17 @@ KMixDockWidget::~KMixDockWidget()
 
 void KMixDockWidget::createActions()
 {
-  // Put "Mute" selector in context menu
-  KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
-  action->setText( i18n( "M&ute" ) );
-  connect(action, SIGNAL(triggered(bool) ), SLOT( dockMute() ));
-  QAction *a = actionCollection()->action( "dock_mute" );
-  QMenu *menu = contextMenu();
-  if ( a ) menu->addAction( a );
+   QMenu *menu = contextMenu();
+
+   MixDevice* md = Mixer::getGlobalMasterMD();
+  if ( md != 0 && md->playbackVolume().hasSwitch() ) {
+    // Put "Mute" selector in context menu
+    KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
+    action->setText( i18n( "M&ute" ) );
+    connect(action, SIGNAL(triggered(bool) ), SLOT( dockMute() ));
+    QAction *a = actionCollection()->action( "dock_mute" );
+    if ( a ) menu->addAction( a );
+}
   
   connect ( this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(kmixSystrayAction(QSystemTrayIcon::ActivationReason) ) );
 
@@ -136,6 +144,16 @@ KMixDockWidget::createMasterVolWidget()
     connect( m_mixer, SIGNAL(controlChanged()), this, SLOT(updatePixmap() ) );
 }
 
+bool KMixDockWidget::eventFilter(QObject * obj, QEvent * e)
+{
+   ViewDockAreaPopup* dockAreaPopup = qobject_cast<ViewDockAreaPopup*>(parent());
+    if ( obj == dockAreaPopup && e->type() == QEvent::Show)
+    {
+        moveVolumePopoup();
+    }
+
+    return false;
+}
 
 void KMixDockWidget::selectMaster()
 {
@@ -367,11 +385,6 @@ void KMixDockWidget::kmixSystrayAction(QSystemTrayIcon::ActivationReason reason)
     if ( reason == QSystemTrayIcon::MiddleClick ) {
          dockMute();
     }
-   else if ( reason == QSystemTrayIcon::Trigger ) {
-         // Move the popup to a suitable place
-         if (_volumePopup)
-            moveVolumePopoup();
-   }
 }
 
 void
@@ -391,14 +404,13 @@ KMixDockWidget::contextMenuAboutToShow()
     }
 
     // Enable/Disable "Muted" menu item
-   ViewDockAreaPopup* dockAreaPopup = qobject_cast<ViewDockAreaPopup*>(parent());
-   if ( dockAreaPopup != 0  ) {
-        MixDevice* md = dockAreaPopup->dockDevice();
-        KToggleAction *dockMuteAction = static_cast<KToggleAction*>(actionCollection()->action("dock_mute"));
-	//kDebug(67100) << "---> md=" << md << "dockMuteAction=" << dockMuteAction << "isMuted=" << md->isMuted();
-        if ( md != 0 && dockMuteAction != 0 ) {
-           dockMuteAction->setChecked( md->isMuted() );
-        }
+    MixDevice* md = Mixer::getGlobalMasterMD();
+    KToggleAction *dockMuteAction = static_cast<KToggleAction*>(actionCollection()->action("dock_mute"));
+    //kDebug(67100) << "---> md=" << md << "dockMuteAction=" << dockMuteAction << "isMuted=" << md->isMuted();
+    if ( md != 0 && dockMuteAction != 0 ) {
+        bool hasSwitch = md->playbackVolume().hasSwitch();
+        dockMuteAction->setEnabled( hasSwitch );
+        dockMuteAction->setChecked( hasSwitch && md->isMuted() );
     }
 }
 
